@@ -11,13 +11,12 @@ class QuickbooksCore(SitesCore):
     """
     Quickbooks object. Please Inheritance it.
     """
-    def get_otp_code(self, code: str = '') -> str:
+    def get_otp_code(self) -> str:
         """
         Please, modify this function in your code
         :return:
         """
-        print('QuickbooksCore get_otp_code() ' + code)
-        return code
+        return ''
 
     def send_message_service_type_not_found(self, manager: str, customer_or_service: str) -> None:
         pass
@@ -63,7 +62,8 @@ class QuickbooksCore(SitesCore):
                 self.wait_element('//div[text()="Let\'s make sure you\'re you"]', timeout=10, is_need_screenshot=False)
                 if self.does_element_displayed('//div[text()="Let\'s make sure you\'re you"]'):
                     self.browser.click_element_when_visible('//span[@id="ius-sublabel-mfa-email-otp"]')
-                    self.browser.click_element_when_visible('//input[@id="ius-mfa-options-submit-btn"]')
+                    if self.does_element_displayed('//input[@id="ius-mfa-options-submit-btn"]'):
+                        self.browser.click_element_when_visible('//input[@id="ius-mfa-options-submit-btn"]')
 
                     self.wait_element('//input[@id="ius-mfa-confirm-code"]')
                     self.browser.input_text(
